@@ -1,5 +1,5 @@
 /* gsasl.c --- Command line interface to libgsasl.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -45,7 +45,7 @@ writeln (const char *str)
 
   if (sockfd)
     {
-      ssize_t len;
+      ssize_t len = 0;
 
 #ifdef HAVE_LIBGNUTLS
       if (using_tls)
@@ -257,21 +257,50 @@ logout (void)
   return 1;
 }
 
+const char version_etc_copyright[] =
+  /* Do *not* mark this string for translation.  %s is a copyright
+     symbol suitable for this locale, and %d is the copyright
+     year.  */
+  "Copyright %s %d Simon Josefsson.";
+
+static void
+emit_bug_reporting_address (void)
+{
+  /* TRANSLATORS: The placeholder indicates the bug-reporting address
+     for this package.  Please add _another line_ saying
+     "Report translation bugs to <...>\n" with the address for translation
+     bugs (typically your translation team's web or email address).  */
+  printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
+}
+
+static void
+usage (int status)
+{
+  if (status != EXIT_SUCCESS)
+    fprintf (stderr, _("Try `%s --help' for more information.\n"),
+	     program_name);
+  else
+    {
+      cmdline_parser_print_help ();
+      emit_bug_reporting_address ();
+    }
+  exit (status);
+}
+
 int
 main (int argc, char *argv[])
 {
   Gsasl *ctx = NULL;
   int res;
   char *in;
-  char *connect_hostname;
-  char *connect_service;
+  char *connect_hostname = NULL;
+  char *connect_service = NULL;
 #ifdef HAVE_LIBGNUTLS
   const int kx_prio[] = { GNUTLS_KX_RSA, GNUTLS_KX_DHE_DSS,
     GNUTLS_KX_DHE_RSA, GNUTLS_KX_ANON_DH, 0
   };
   gnutls_anon_client_credentials anoncred;
   gnutls_certificate_credentials x509cred;
-  int ret, outerr;
 #endif
 
   set_program_name (argv[0]);
@@ -293,7 +322,17 @@ main (int argc, char *argv[])
 #endif
 
   if (cmdline_parser (argc, argv, &args_info) != 0)
-    return 1;
+    return EXIT_FAILURE;
+
+  if (args_info.version_given)
+    {
+      version_etc (stdout, "gsasl", PACKAGE_NAME, VERSION,
+		   "Simon Josefsson", (char *) NULL);
+      return EXIT_SUCCESS;
+    }
+
+  if (args_info.help_given)
+    usage (EXIT_SUCCESS);
 
   if (!(args_info.client_flag || args_info.client_given) &&
       !args_info.server_given &&
@@ -733,7 +772,7 @@ main (int argc, char *argv[])
 	    }
 
 	  if (res != GSASL_OK)
-	    error (EXIT_FAILURE, 0, _("encoding error: %s"), res,
+	    error (EXIT_FAILURE, 0, _("encoding error: %s"),
 		   gsasl_strerror (res));
 	}
 
